#!/usr/bin/env python
# -*- coding: utf-8 -*-

import hashlib
import datetime
import requests

API_BASE = 'https://open.koudaitong.com/api/entry'


class YouZan(object):
    """docstring for YouZan"""
    def __init__(self, app_id=None, app_secert=None):
        self.app_id = app_id
        self.app_secert = app_secert
        self.format = 'json'
        self.v = '1.0'
        self.sign_method = 'md5'


    def get_sign(self, args_dict):
        arg_str = ''.join(
            ['%s%s' % (key, args_dict[key])
                for key in sorted(args_dict)])
        arg_str = "{}{}{}".format(self.app_secert, arg_str, self.app_secert)
        return hashlib.md5(arg_str).hexdigest().lower()

    def __call__(self, method, **args):
        timestamp = datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S")

        args_dict = {}
        args_dict['app_id'] = self.app_id
        args_dict['format'] = self.format
        args_dict['sign_method'] = self.sign_method
        args_dict['v'] = self.v
        args_dict['method'] = method
        args_dict['timestamp'] = timestamp
        args_dict.update(args)

        payload = args_dict.copy()
        payload['sign'] = self.get_sign(args_dict)

        r = requests.get(API_BASE, params=payload)
        return r.json()



'''
    youzan
    -----------

    youzan provides the Youzan SDK for Python.

'''
from setuptools import setup

setup(
    name='youzan',
    version='0.1.3',
    url='https://github.com/fengluo/youzan',
    license='MIT',
    author='fengluo',
    author_email='fengluo17@gmail.com',
    description='Youzan SDK for Python',
    long_description=__doc__,
    py_modules=['youzan'],
    zip_safe=False,
    packages=['youzan'],
    install_requires=['requests', ''],
    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ])
